@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2006-2010 Bastian Kleineidam
+# Copyright (C) 2006-2011 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@ Cache for DNS lookups.
 """
 import socket
 import sys
+from .. import LinkCheckerError
 from ..lock import get_lock
 from ..containers import LFUCache
 from ..decorators import synchronized
@@ -28,14 +29,26 @@ addrinfos = LFUCache(size=10000)
 
 @synchronized(_lock)
 def getaddrinfo (host, port):
+    """Determine address information for given host and port for
+    streaming sockets (SOCK_STREAM).
+    Already cached information is used."""
     key = u"%s:%s" % (unicode(host), unicode(port))
     if key in addrinfos:
         value = addrinfos[key]
     else:
+        # check if it's an ascii host
+        if isinstance(host, unicode):
+            try:
+                host = host.encode('ascii')
+            except UnicodeEncodeError:
+                pass
         try:
             value = socket.getaddrinfo(host, port, 0, socket.SOCK_STREAM)
         except socket.error:
             value = sys.exc_info()[1]
+        except UnicodeError, msg:
+            args = dict(host=host, msg=str(msg))
+            value = LinkCheckerError(_("could not parse host %(host)r: %(msg)s") % args)
         addrinfos[key] = value
     if isinstance(value, Exception):
         raise value
