@@ -132,6 +132,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         """
         # set the proxy, so a 407 status after this is an error
         self.set_proxy(self.aggregate.config["proxy"].get(self.scheme))
+        self.construct_auth()
         # check robots.txt
         if not self.allows_robots(self.url):
             # remove all previously stored results
@@ -182,18 +183,14 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
                 # some servers send empty HEAD replies
                 if self.method == "HEAD" and self.method_get_allowed:
                     log.debug(LOG_CHECK, "Bad status line %r: falling back to GET", msg)
-                    self.method = "GET"
-                    self.aliases = []
-                    self.fallback_get = True
+                    self.fallback_to_get()
                     continue
                 raise
             except socket.error, msg:
                 # some servers reset the connection on HEAD requests
                 if self.method == "HEAD" and self.method_get_allowed and \
                    msg[0] == errno.ECONNRESET:
-                    self.method = "GET"
-                    self.aliases = []
-                    self.fallback_get = True
+                    self.fallback_to_get()
                     continue
                 raise
             if response.reason:
@@ -225,9 +222,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
                 # some servers send empty HEAD replies
                 if self.method == "HEAD" and self.method_get_allowed:
                     log.debug(LOG_CHECK, "Bad status line %r: falling back to GET", msg)
-                    self.method = "GET"
-                    self.aliases = []
-                    self.fallback_get = True
+                    self.fallback_to_get()
                     continue
                 raise
             if tries == -1:
@@ -238,9 +233,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
             if tries >= self.max_redirects:
                 if self.method == "HEAD" and self.method_get_allowed:
                     # Microsoft servers tend to recurse HEAD requests
-                    self.method = "GET"
-                    self.aliases = []
-                    self.fallback_get = True
+                    self.fallback_to_get()
                     continue
                 self.set_result(_("more than %d redirections, aborting") %
                                 self.max_redirects, valid=False)
@@ -257,40 +250,40 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
                        tag=WARN_HTTP_AUTH_UNKNOWN)
                     return
                 if not self.auth:
-                    _user, _password = self.get_user_password()
-                    self.auth = "Basic " + \
-                        httputil.encode_base64("%s:%s" % (_user, _password))
-                    log.debug(LOG_CHECK,
-                        "Authentication %s/%s", _user, _password)
+                    self.construct_auth()
                     continue
-            elif response.status >= 400:
-                # Retry with GET, but do not set fallback_get flag.
-                # This ensures that sites that do not properly support HEAD
-                # requests do not give false errors.
-                if self.method == "HEAD" and self.method_get_allowed:
-                    # The squid proxy reports valid 200 instead of 404 due to
-                    # garbage sent from the server at the start of the GET
-                    # request. See http://www.aldec.com/Products
-                    if u'squid' not in self.getheader('Via', u'').lower():
-                        self.method = "GET"
-                        self.aliases = []
-                        continue
-            elif self.headers and self.method == "HEAD" and self.method_get_allowed:
+            if (self.headers and self.method == "HEAD" and
+                self.method_get_allowed):
                 # test for HEAD support
-                mime = self.get_content_type()
                 poweredby = self.getheader('X-Powered-By', u'')
                 server = self.getheader('Server', u'')
                 if (poweredby.startswith('Zope') or server.startswith('Zope')
                  or ('ASP.NET' in poweredby and 'Microsoft-IIS' in server)):
                     # Zope or IIS server could not get Content-Type with HEAD
-                    # see http://intermapper.com.dev4.silvertech.net/bogus.aspx
-                    self.method = "GET"
-                    self.aliases = []
-                    self.fallback_get = True
+                    # http://intermapper.com.dev4.silvertech.net/bogus.aspx
+                    self.fallback_to_get()
                     continue
             break
         return response
 
+    def fallback_to_get(self):
+        """Set method to GET and set fallback flag."""
+        self.method = "GET"
+        self.aliases = []
+        self.fallback_get = True
+
+    def construct_auth (self):
+        """Construct HTTP Basic authentication credentials if there
+        is user/password information available. Does not overwrite if
+        credentials have already been constructed."""
+        if self.auth:
+            return
+        _user, _password = self.get_user_password()
+        if _user is not None and _password is not None:
+            credentials = httputil.encode_base64("%s:%s" % (_user, _password))
+            self.auth = "Basic " + credentials
+            log.debug(LOG_CHECK, "Using basic authentication")
+
     def get_content_type (self):
         """Return content MIME type or empty string."""
         if self.content_type is None:
@@ -324,6 +317,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
         self.add_info(_("Redirected to `%(url)s'.") % {'url': newurl})
         # norm base url - can raise UnicodeError from url.idna_encode()
         redirected, is_idn = urlbase.url_norm(newurl)
+        # XXX recalculate authentication information when available
         log.debug(LOG_CHECK, "Norm redirected to %r", redirected)
         urlparts = strformat.url_unicode_split(redirected)
         if not self.check_redirection_scheme(redirected, urlparts, set_result):
@@ -370,6 +364,7 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
 
     def check_redirection_domain (self, redirected, urlparts, set_result, response):
         """Return True if redirection domain is ok, else False."""
+        # XXX does not support user:pass@netloc format
         if urlparts[1] != self.urlparts[1]:
             # URL domain changed
             if self.recursion_level == 0 and urlparts[0] in ('http', 'https'):
@@ -540,11 +535,8 @@ class HttpUrl (internpaturl.InternPatternUrl, proxysupport.ProxySupport):
                                        skip_accept_encoding=True)
         # be sure to use the original host as header even for proxies
         self.url_connection.putheader("Host", self.urlparts[1])
-        # userinfo is from http://user@pass:host/
-        if self.userinfo:
-            self.url_connection.putheader("Authorization", self.userinfo)
-        # auth is the -u and -p configuration options
-        elif self.auth:
+        if self.auth:
+            # HTTP authorization
             self.url_connection.putheader("Authorization", self.auth)
         if self.proxyauth:
             self.url_connection.putheader("Proxy-Authorization",
