@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2005-2011 Bastian Kleineidam
+# Copyright (C) 2005-2012 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -252,6 +252,8 @@ class HttpCookie (object):
                 if key.startswith("$"):
                     key = key[1:]
                 self.set_attribute(key, value)
+        if self.name is None:
+            raise CookieError("missing cookie name in %r" % text)
         self.calculate_expiration()
 
     def set_default_attributes (self, scheme, host, path):
