@@ -47,9 +47,13 @@ class CSVLogger (Logger):
             return sys.stdout
         return open(self.filename, "wb")
 
+    def write (self, s, **args):
+        """Write encoded string."""
+        super(CSVLogger, self).write(self.encode(s), **args)
+
     def comment (self, s, **args):
         """Write CSV comment."""
-        self.writeln(s=self.encode(u"# %s" % s), **args)
+        self.writeln(s=u"# %s" % s, **args)
 
     def start_output (self):
         """Write checking start info as csv comment."""
