@@ -219,8 +219,15 @@ def strduration (duration):
 
 
 # from quodlibet
-def strduration_long (duration):
+def strduration_long (duration, do_translate=True):
     """Turn a time value in seconds into x hours, x minutes, etc."""
+    if do_translate:
+        # use global translator functions
+        global _, _n
+    else:
+        # do not translate
+        _ = lambda x: x
+        _n = lambda a, b, n: a if n==1 else b
     if duration < 0:
         duration = abs(duration)
         prefix = "-"
@@ -297,3 +304,10 @@ def limit (s, length=72):
 def strline (s):
     """Display string representation on one line."""
     return u"`%s'" % unicode(s).replace(u"\n", u"\\n")
+
+
+def format_feature_warning (**kwargs):
+    """Format warning that a module could not be imported and that it should
+    be installed for a certain URL.
+    """
+    return _("Could not import %(module)s for %(feature)s. Install %(module)s from %(url)s to use this feature.") % kwargs
