@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# Copyright (C) 2004-2011 Bastian Kleineidam
+# Copyright (C) 2004-2012 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -136,7 +136,7 @@ class TestStrFormat (unittest.TestCase):
         self.assertEqual(duration(60*60*24), "24:00:00")
 
     def test_duration_long (self):
-        duration = linkcheck.strformat.strduration_long
+        duration = lambda s: linkcheck.strformat.strduration_long(s, do_translate=False)
         self.assertEqual(duration(-0.5), "-0.50 seconds")
         self.assertEqual(duration(0), "0.00 seconds")
         self.assertEqual(duration(0.9), "0.90 seconds")
